

zetup.py
========



|image0| |image1|

.. |image0| image:: https://pypip.in/v/zetup/badge.svg
   :target: https://pypi.python.org/pypi/zetup
.. |image1| image:: https://travis-ci.org/userzimmermann/zetup.py.svg?branch=master
   :target: https://travis-ci.org/userzimmermann/zetup.py



Zimmermann's `Python <http://python.org>`__ package setup
---------------------------------------------------------



https://bitbucket.org/userzimmermann/zetup.py

https://github.com/userzimmermann/zetup.py

